@@ -51,8 +51,12 @@
 #include <QVBoxLayout>
 
 // KDE Frameworks
-#include "kimagemapeditor_debug.h"
+#include <kwidgetsaddons_version.h>
+#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
+#include <KPluginMetaData>
+#else
 #include <KAboutData>
+#endif
 #include <KActionCollection>
 #include <KConfigGroup>
 #include <KIO/Job>
@@ -65,6 +69,7 @@
 #include <KXmlGuiWindow>
 
 // local
+#include "kimagemapeditor_debug.h"
 #include "drawzone.h"
 #include "kimedialogs.h"
 #include "kimecommands.h"
@@ -76,23 +81,30 @@
 #include "imagemapchoosedialog.h"
 #include "kimagemapeditor_version.h"
 
-K_PLUGIN_FACTORY(KImageMapEditorFactory, registerPlugin<KImageMapEditor>();)
+K_PLUGIN_FACTORY_WITH_JSON(KImageMapEditorFactory, "kimagemapeditorpart.json", registerPlugin<KImageMapEditor>();)
 
-KImageMapEditor::KImageMapEditor(QWidget *parentWidget,
-            QObject *parent, const QVariantList & )
+KImageMapEditor::KImageMapEditor(QWidget *parentWidget, QObject *parent,
+#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
+                                 const KPluginMetaData &metaData,
+#endif
+                                 const QVariantList & )
   : KParts::ReadWritePart(parent)
 {
+#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
+  setMetaData(metaData);
+#else
   KAboutData aboutData( "kimagemapeditor", i18n("KImageMapEditor"),
               KIMAGEMAPEDITOR_VERSION_STRING, i18n( "An HTML imagemap editor" ),
               KAboutLicense::GPL,
-              i18n("(c) 2001-2003 Jan Sch&auml;fer <email>janschaefer@users.sourceforge.net</email>"));
+              i18n("Copyright 2001-2003 Jan Schäfer <janschaefer@users.sourceforge.net>"));
   setComponentData(aboutData, false);
+#endif
 
 //  KDockMainWindow* mainWidget;
 
   mainWindow = dynamic_cast<KXmlGuiWindow*>(parent) ;
-  QSplitter * splitter = 0L;
-  tabWidget = 0L;
+  QSplitter * splitter = nullptr;
+  tabWidget = nullptr;
 
   if (mainWindow) {
 //    qCDebug(KIMAGEMAPEDITOR_LOG) << "KImageMapEditor: We got a KDockMainWindow !";
@@ -122,9 +134,9 @@ KImageMapEditor::KImageMapEditor(QWidget *parentWidget,
   }
   else
   {
-    areaDock = 0L;
-    mapsDock = 0L;
-    imagesDock = 0L;
+    areaDock = nullptr;
+    mapsDock = nullptr;
+    imagesDock = nullptr;
     splitter = new QSplitter(parentWidget);
     tabWidget = new QTabWidget(splitter);
     areaListView = new AreaListView(tabWidget);
@@ -173,7 +185,7 @@ KImageMapEditor::KImageMapEditor(QWidget *parentWidget,
     setWidget(splitter);
   } else {
     QScrollArea *sa = new QScrollArea(mainWindow);
-    drawZone = new DrawZone(0L,this);
+    drawZone = new DrawZone(nullptr,this);
     mainWindow->setCentralWidget(sa);
     sa->setWidget(drawZone);
     setWidget(mainWindow);
@@ -184,9 +196,9 @@ KImageMapEditor::KImageMapEditor(QWidget *parentWidget,
   areas = new AreaList();
   currentSelected= new AreaSelection();
   _currentToolType=KImageMapEditor::Selection;
-  copyArea=0L;
-  defaultArea=0L;
-  currentMapElement = 0L;
+  copyArea = nullptr;
+  defaultArea = nullptr;
+  currentMapElement = nullptr;
 
   setupActions();
   setupStatusBar();
@@ -221,6 +233,16 @@ KImageMapEditor::~KImageMapEditor() {
 
 }
 
+QString KImageMapEditor::componentName() const
+{
+    // the part ui.rc file is in the program folder, not a separate one
+    // TODO: change the component name to "kimagemapeditorpart" by removing this method and
+    // adapting the folder where the file is placed.
+    // Needs a way to also move any potential custom user ui.rc files
+    // from kimagemapeditor/ to kimagemapeditorpart/
+    return QStringLiteral("kimagemapeditor");
+}
+
 MapTag::MapTag() {
   modified = false;
   name.clear();
@@ -504,7 +526,11 @@ void KImageMapEditor::setupActions()
   // View Zoom
   zoomAction  = new KSelectAction(i18n("Zoom"), this);
   actionCollection()->addAction("view_zoom", zoomAction );
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 78, 0)
+  connect(zoomAction, &KSelectAction::indexTriggered, this, &KImageMapEditor::slotZoom);
+#else
   connect(zoomAction, SIGNAL(triggered(int)), this, SLOT (slotZoom()));
+#endif
   zoomAction->setWhatsThis(i18n("<h3>Zoom</h3>"
                           "Choose the desired zoom level."));
   zoomAction->setItems(QStringList()
@@ -976,7 +1002,7 @@ void KImageMapEditor::addArea(Area* area) {
   // Perhaps we've got a selection of areas
   // so test it and add all areas of the selection
   // nested selections are possible but doesn't exist
-  AreaSelection *selection=0L;
+  AreaSelection *selection = nullptr;
   if ( (selection = dynamic_cast <AreaSelection*> ( area ) ) )
   {
     AreaListIterator it = selection->getAreaListIterator();
@@ -1028,7 +1054,7 @@ void KImageMapEditor::deleteArea( Area * area )
   // Perhaps we've got a selection of areas
   // so test it and delete the whole selection
   // nested selections are possible but doesn't exist
-  AreaSelection *selection=0L;
+  AreaSelection *selection = nullptr;
     if ( (selection = dynamic_cast <AreaSelection*> ( area ) ) )
   {
     AreaListIterator it = selection->getAreaListIterator();
@@ -1173,7 +1199,7 @@ void KImageMapEditor::slotAreaChanged(Area *area)
 
   setModified(true);
 
-  AreaSelection *selection=0L;
+  AreaSelection *selection = nullptr;
   if ( (selection = dynamic_cast <AreaSelection*> ( area ) ) )
   {
     AreaListIterator it = selection->getAreaListIterator();
@@ -1347,7 +1373,7 @@ Area* KImageMapEditor::onArea(const QPoint & p) const {
     if (s->contains(p))
       return s;
   }
-  return 0L;
+  return nullptr;
 }
 
 
@@ -1859,13 +1885,13 @@ bool KImageMapEditor::openHTMLFile(const QUrl & url)
   f.open(QIODevice::ReadOnly);
   QTextStream s(&f);
   QChar w;
-  QHash<QString,QString> *attr=0L;
+  QHash<QString,QString> *attr = nullptr;
   QList<ImageTag*> images;
-  MapTag *map=0L;
+  MapTag *map = nullptr;
   QList<MapTag*> maps;
 
   _htmlContent.clear();
-  currentMapElement = 0L;
+  currentMapElement = nullptr;
 
   QString temp;
   QString origcode;
@@ -1936,7 +1962,7 @@ bool KImageMapEditor::openHTMLFile(const QUrl & url)
 
   QUrl imageUrl;
 
-  map = 0L;
+  map = nullptr;
 
     // If we have more than on map or more than one image
     // Let the user choose, otherwise take the only ones
@@ -2056,7 +2082,7 @@ HtmlElement* KImageMapEditor::findHtmlElement(const QString & containingText) {
       return el;
     }
   }
-  return 0L;
+  return nullptr;
 }
 
 /**
@@ -2072,7 +2098,7 @@ HtmlImgElement* KImageMapEditor::findHtmlImgElement(ImageTag* tag) {
     if (imgEl && imgEl->imgTag == tag)
        return imgEl;
   }
-  return 0L;
+  return nullptr;
 }
 
 void KImageMapEditor::addMap(const QString & name = QString()) {
@@ -2121,7 +2147,7 @@ HtmlMapElement* KImageMapEditor::findHtmlMapElement(const QString & mapName) {
   }
 
   qCWarning(KIMAGEMAPEDITOR_LOG) << "KImageMapEditor::findHtmlMapElement: couldn't find map '" << mapName << "'";
-  return 0L;
+  return nullptr;
 }
 
 /**
@@ -2215,7 +2241,7 @@ void KImageMapEditor::setMap(HtmlMapElement* mapElement) {
   // Remove old areas only if a new map is loaded
   deleteAllAreas();
   delete defaultArea;
-  defaultArea = 0L;
+  defaultArea = nullptr;
 //    qCDebug(KIMAGEMAPEDITOR_LOG) << "KImageMapEditor::setMap : Setting new map : " << map->name;
     _mapName = map->name;
     AreaTag tag;
@@ -2472,7 +2498,7 @@ void KImageMapEditor::slotBackOne()
   AreaList list = currentSelected->getAreaList();
 
 
-  Area *a = 0L;
+  Area *a = nullptr;
   // move every selected Area one step lower
   for (int i=areas->count()-2; i > -1; i--)
   {
@@ -2498,7 +2524,7 @@ void KImageMapEditor::slotForwardOne()
 
   AreaList list = currentSelected->getAreaList();
 
-  Area *a = 0L;
+  Area *a = nullptr;
   // move every selected Area one step higher
   for (int i=1; i < (int)areas->count(); i++)
   {
@@ -2697,7 +2723,7 @@ void KImageMapEditor::mapDelete()
   _htmlContent.removeAll(mapEl);
   if (mapsListView->count() == 0) {
 
-      currentMapElement = 0L;
+      currentMapElement = nullptr;
       deleteAllAreas();
       setMapActionsEnabled(false);
   }
@@ -2760,12 +2786,12 @@ bool KImageMapEditor::closeUrl()
   imagesListView->clear();
 
   delete copyArea;
-  copyArea=0L;
+  copyArea = nullptr;
 
   delete defaultArea;
-  defaultArea=0L;
+  defaultArea = nullptr;
 
-  currentMapElement = 0L;
+  currentMapElement = nullptr;
 
   init();
   emit setWindowCaption("");
